# inspect_viz

Learn more about Inspect Viz at <https://meridianlabs-ai.github.io/inspect_viz/>.

## Installation

```bash
pip install git+https://github.com/meridianlabs-ai/inspect_viz
```

## Development

For Python development:

```sh
pip install -e ".[dev]"
```

For JS / front-end development:

```sh
yarn install
```

While developing, you can run the following in a separate terminal to automatically rebuild JavaScript as you make changes:

```sh
yarn dev # or
yarn dev-sourcemap
```
